@@ -9,6 +9,8 @@
  * Refer to the COPYING file of the official project for license.
  *****************************************************************************/
 
+import CoreSpotlight
+
 protocol MediaModel: MLBaseModel where MLType == VLCMLMedia { }
 
 extension MediaModel {
@@ -31,17 +33,13 @@ extension MediaModel {
 
 extension VLCMLMedia {
     func deleteMainFile() {
-        do {
-            if let mainFile = mainFile() {
-                try FileManager.default.removeItem(atPath: mainFile.mrl.path)
-            }
-        } catch let error as NSError {
-            assertionFailure("VLCMLMedia: Delete failed: \(error.localizedDescription)")
+        if let mainFile = mainFile() {
+            mainFile.delete()
         }
     }
 
     @objc func mediaDuration() -> String {
-        return String(format: "%@", VLCTime(int: Int32(duration())))
+        return String(format: "%@", VLCTime(number: NSNumber.init(value: duration())))
     }
 
     @objc func formatSize() -> String {
@@ -50,11 +48,11 @@ extension VLCMLMedia {
     }
 
     @objc func thumbnailImage() -> UIImage? {
-        var image = UIImage(contentsOfFile: thumbnail()?.path ?? "")
+        var image = VLCThumbnailsCache.thumbnail(for: thumbnail())
         if image == nil
             || (!UserDefaults.standard.bool(forKey: kVLCSettingShowThumbnails) && subtype() != .albumTrack)
             || (!UserDefaults.standard.bool(forKey: kVLCSettingShowArtworks) && subtype() == .albumTrack) {
-            let isDarktheme = PresentationTheme.current == PresentationTheme.darkTheme
+            let isDarktheme = PresentationTheme.current.isDark
             if subtype() == .albumTrack {
                 image = isDarktheme ? UIImage(named: "song-placeholder-dark") : UIImage(named: "song-placeholder-white")
             } else {
