@@ -1245,18 +1245,18 @@ private extension VideoPlayerViewController {
 
     private func videoPlayerButtons() {
         let audioMedia: Bool = playbackService.metadata.isAudioOnly
-        if view.frame.width >= DeviceWidth.iPhone12ProMaxPortrait.rawValue {
+        if audioMedia {
             videoPlayerControls.repeatButton.isHidden = false
             videoPlayerControls.shuffleButton.isHidden = false
 
+            videoPlayerControls.subtitleButton.isHidden = true
+            videoPlayerControls.aspectRatioButton.isHidden = true
+        } else {
+            videoPlayerControls.repeatButton.isHidden = true
+            videoPlayerControls.shuffleButton.isHidden = true
+
             videoPlayerControls.subtitleButton.isHidden = false
             videoPlayerControls.aspectRatioButton.isHidden = false
-        } else {
-            videoPlayerControls.repeatButton.isHidden = !audioMedia
-            videoPlayerControls.shuffleButton.isHidden = !audioMedia
-
-            videoPlayerControls.subtitleButton.isHidden = audioMedia
-            videoPlayerControls.aspectRatioButton.isHidden = audioMedia
         }
     }
     // MARK: - Constraints
@@ -1764,6 +1764,22 @@ extension VideoPlayerViewController: MediaMoreOptionsActionSheetDelegate {
             playbackService.playPause()
         }
     }
+
+    private func openOptionView(view: MediaPlayerActionSheetCellIdentifier) {
+        present(moreOptionsActionSheet, animated: true, completion: {
+            self.moreOptionsActionSheet.addView(view)
+        })
+    }
+
+    func mediaMoreOptionsActionSheetDidToggleShuffle(_ mediaMoreOptionsActionSheet: MediaMoreOptionsActionSheet) {
+        videoPlayerControlsDelegateShuffle(videoPlayerControls)
+        mediaMoreOptionsActionSheet.collectionView.reloadData()
+    }
+
+    func mediaMoreOptionsActionSheetDidTapRepeat(_ mediaMoreOptionsActionSheet: MediaMoreOptionsActionSheet) {
+        videoPlayerControlsDelegateRepeat(videoPlayerControls)
+        mediaMoreOptionsActionSheet.collectionView.reloadData()
+    }
 }
 
 // MARK: - OptionsNavigationBarDelegate
