@@ -104,7 +104,6 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
     if (self) {
         _fullscreenSessionRequested = YES;
         // listen to audiosessions and appkit callback
-        _externalAudioPlaybackDeviceConnected = [self isExternalAudioPlaybackDeviceConnected];
         NSNotificationCenter *defaultCenter = [NSNotificationCenter defaultCenter];
         [defaultCenter addObserver:self selector:@selector(audioSessionRouteChange:)
                               name:AVAudioSessionRouteChangeNotification object:nil];
@@ -140,6 +139,9 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
         _mediaList = [[VLCMediaList alloc] init];
 
         _openedLocalURLs = [[NSMutableArray alloc] init];
+        dispatch_async(dispatch_get_main_queue(), ^{
+            self->_externalAudioPlaybackDeviceConnected = [self isExternalAudioPlaybackDeviceConnected];
+        });
     }
     return self;
 }
@@ -154,9 +156,9 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 }
 #pragma mark - playback management
 
-- (void)openVideoSubTitlesFromFile:(NSString *)pathToFile
+- (void)addSubtitlesToCurrentPlaybackFromURL:(NSURL *)subtitleURL
 {
-    [_mediaPlayer addPlaybackSlave:[NSURL fileURLWithPath:pathToFile] type:VLCMediaPlaybackSlaveTypeSubtitle enforce:YES];
+    [_mediaPlayer addPlaybackSlave:subtitleURL type:VLCMediaPlaybackSlaveTypeSubtitle enforce:YES];
 }
 
 - (void)playMediaList:(VLCMediaList *)mediaList firstIndex:(NSInteger)index subtitlesFilePath:(NSString * _Nullable)subsFilePath
@@ -305,12 +307,13 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
         APLog(@"%s: locking failed", __PRETTY_FUNCTION__);
         return;
     }
+    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
 
     // Set last selected equalizer profile if enabled
-    _mediaPlayer.equalizerEnabled = ![[NSUserDefaults standardUserDefaults] boolForKey:kVLCSettingEqualizerProfileDisabled];
+    _mediaPlayer.equalizerEnabled = ![userDefaults boolForKey:kVLCSettingEqualizerProfileDisabled];
 
     if (_mediaPlayer.equalizerEnabled) {
-        unsigned int profile = (unsigned int)[[[NSUserDefaults standardUserDefaults] objectForKey:kVLCSettingEqualizerProfile] integerValue];
+        unsigned int profile = (unsigned int)[userDefaults integerForKey:kVLCSettingEqualizerProfile];
         [_mediaPlayer resetEqualizerFromProfile:profile];
         [_mediaPlayer setPreAmplification:[_mediaPlayer preAmplification]];
     }
@@ -1102,12 +1105,19 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 
 - (void)resetEqualizerFromProfile:(unsigned int)profile
 {
-    _mediaPlayer.equalizerEnabled = profile != 0;
-    [[NSUserDefaults standardUserDefaults] setBool:profile == 0 forKey:kVLCSettingEqualizerProfileDisabled];
-    if (profile != 0) {
-        [[NSUserDefaults standardUserDefaults] setObject:@(profile - 1) forKey:kVLCSettingEqualizerProfile];
-        [_mediaPlayer resetEqualizerFromProfile:profile - 1];
+    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
+    if (profile == 0) {
+        _mediaPlayer.equalizerEnabled = NO;
+        [userDefaults setBool:YES forKey:kVLCSettingEqualizerProfileDisabled];
+        return;
     }
+
+    [userDefaults setBool:NO forKey:kVLCSettingEqualizerProfileDisabled];
+    _mediaPlayer.equalizerEnabled = YES;
+
+    unsigned int actualProfile = profile - 1;
+    [userDefaults setInteger:actualProfile forKey:kVLCSettingEqualizerProfile];
+    [_mediaPlayer resetEqualizerFromProfile:actualProfile];
 }
 
 - (void)setPreAmplification:(CGFloat)preAmplification
@@ -1133,6 +1143,18 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
     return [_mediaPlayer frequencyOfBandAtIndex:index];
 }
 
+- (unsigned int)selectedEqualizerProfile
+{
+    /* this is a bit complex, if the eq is off, we need to return 0
+     * if it is on, we need to provide the profile + 1 as the UI fakes a "Off" profile in its list */
+    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
+    if ([userDefaults boolForKey:kVLCSettingEqualizerProfileDisabled]) {
+        return 0;
+    }
+    unsigned int actualProfile = (unsigned int)[userDefaults integerForKey:kVLCSettingEqualizerProfile];
+    return actualProfile + 1;
+}
+
 #pragma mark - AVAudioSession Notification Observers
 
 - (void)handleInterruption:(NSNotification *)notification
@@ -1209,15 +1231,17 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
 {
     if (_needsMetadataUpdate == NO) {
         _needsMetadataUpdate = YES;
-        dispatch_async(dispatch_get_main_queue(), ^{
+        dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_LOW, 0), ^{
 #if TARGET_OS_IOS
             VLCMLMedia *media = self->_mediaPlayer.media ? [self->_delegate mediaForPlayingMedia:self->_mediaPlayer.media] : nil;
             [self->_metadata updateMetadataFromMedia:media mediaPlayer:self->_mediaPlayer];
 #else
             [self->_metadata updateMetadataFromMediaPlayer:self->_mediaPlayer];
 #endif
-            self->_needsMetadataUpdate = NO;
-            [self recoverDisplayedMetadata];
+            dispatch_async(dispatch_get_main_queue(), ^{
+                self->_needsMetadataUpdate = NO;
+                [self recoverDisplayedMetadata];
+            });
         });
     }
 }
